class puppet_enterprise::profile::puppetdb(
  $database_host       = $puppet_enterprise::database_host,
  $master_certname     = $puppet_enterprise::puppet_master_host,
  $whitelisted_certnames = [],
  $certname            = $::clientcert,
  $confdir             = $puppet_enterprise::params::puppetdb_confdir,
  $database_name       = $puppet_enterprise::puppetdb_database_name,
  $database_password   = $puppet_enterprise::puppetdb_database_password,
  $database_port       = $puppet_enterprise::database_port,
  $database_user       = $puppet_enterprise::puppetdb_database_user,
  $listen_address      = $puppet_enterprise::params::plaintext_address,
  $listen_port         = $puppet_enterprise::params::puppetdb_listen_port,
  $ssl_listen_address  = $puppet_enterprise::params::ssl_address,
  $ssl_listen_port     = $puppet_enterprise::puppetdb_port,
  $localcacert         = $puppet_enterprise::params::localcacert,
  $database_properties = $puppet_enterprise::database_properties,
  $java_args           = $puppet_enterprise::params::puppetdb_java_args,
) inherits puppet_enterprise {

  class { 'puppet_enterprise::puppetdb':
    certname            => $certname,
    confdir             => $confdir,
    database_name       => $database_name,
    database_port       => $database_port,
    database_host       => $database_host,
    database_user       => $database_user,
    database_password   => $database_password,
    listen_address      => $listen_address,
    listen_port         => $listen_port,
    ssl_listen_address  => $ssl_listen_address,
    ssl_listen_port     => $ssl_listen_port,
    localcacert         => $localcacert,
    database_properties => $database_properties,
    java_args           => $java_args,
  }

  file { $puppet_enterprise::params::puppetdb_ssl_dir :
    ensure => directory,
    mode   => '0600',
    owner  => 'pe-puppetdb',
    group  => 'pe-puppetdb',
    before => Puppet_enterprise::Certs['pe-puppetdb'],
  }
  puppet_enterprise::certs { 'pe-puppetdb' :
    certname => $certname,
    owner    => 'pe-puppetdb',
    group    => 'pe-puppetdb',
    cert_dir => $puppet_enterprise::params::puppetdb_ssl_dir,
  }

  file { $puppet_enterprise::params::puppetdb_cert_whitelist_path:
    ensure => file,
    group  => 'pe-puppetdb',
    owner  => 'pe-puppetdb',
    mode   => '0640',
  }

  $certs = pe_union(['pe-internal-dashboard', $master_certname, $certname], $whitelisted_certnames)
  puppet_enterprise::certs::puppetdb_whitelist_entry { $certs: }
  Puppet_enterprise::Certs::Puppetdb_whitelist_entry <<| certname != $master_certname and certname != $certname |>>
}
