class puppet_enterprise::puppetdb(
  $database_host,
  $certname            = $::clientcert,
  $confdir             = $puppet_enterprise::params::puppetdb_confdir,
  $database_name       = $puppet_enterprise::params::puppetdb_database_name,
  $database_password   = undef,
  $database_port       = $puppet_enterprise::params::puppetdb_database_port,
  $database_user       = $puppet_enterprise::params::puppetdb_database_user,
  $listen_address      = $puppet_enterprise::params::plaintext_address,
  $listen_port         = $puppet_enterprise::params::puppetdb_listen_port,
  $ssl_listen_address  = $puppet_enterprise::params::ssl_address,
  $ssl_listen_port     = $puppet_enterprise::params::puppetdb_ssl_listen_port,
  $localcacert         = $puppet_enterprise::params::localcacert,
  $database_properties = '',
  $java_args           = $puppet_enterprise::params::puppetdb_java_args,
) inherits puppet_enterprise::params {

  include puppet_enterprise::packages
  Package <| tag == 'pe-puppetdb-packages' |>

  class { 'puppet_enterprise::puppetdb::database_ini':
    confdir             => $confdir,
    database_host       => $database_host,
    database_name       => $database_name,
    database_password   => $database_password,
    database_port       => $database_port,
    database_user       => $database_user,
    database_properties => $database_properties,
  }

  class { 'puppet_enterprise::puppetdb::jetty_ini':
    certname           => $certname,
    confdir            => $confdir,
    listen_address     => $listen_address,
    listen_port        => $listen_port,
    ssl_listen_address => $ssl_listen_address,
    ssl_listen_port    => $ssl_listen_port,
    localcacert        => $localcacert,
  }

  class { 'puppet_enterprise::puppetdb::service': }

  file { '/var/log/pe-puppetdb':
    ensure => directory,
    owner  => 'pe-puppetdb',
    group  => 'pe-puppetdb',
    mode   => '0640',
  }

  file { '/var/log/pe-puppetdb/pe-puppetdb.log':
    ensure  => present,
    owner   => 'pe-puppetdb',
    group   => 'pe-puppetdb',
    mode    => '0640',
  }

  if !pe_empty($java_args) {
    $puppetdb_initconf = "${puppet_enterprise::params::defaults_dir}/pe-puppetdb"

    create_resources(
      'pe_ini_subsetting',
      create_java_args_subsettings_hash(
        'pe-puppetdb',
        $java_args,
        { path => $puppetdb_initconf,
          require => Package['pe-puppetdb'],
          notify => Service['pe-puppetdb'],
        })
    )
  }

}
